
#### DISCLAIMER ####

# This script was used to generate figures visualising data from an Acoustic Zooplankton and Fish Profiler (AZFP)
# deployed in the Arctic Ocean from 09-18-2020 to 03-31-2021. The figures were part of the scientific publication
# "Sea-ice decline could keep zooplankton deeper for longer" by H. Flores, G. Veyssiere, G. Castellani, J. Wilkinson, M. Hoppmann, M. Karcher, 
# L. Valcic, A. Cornils, M. Geoffroy, M. Nicolaus, B. Niehoff, P. Priou, K. Schmidt & J. Stroeve, 
# published in the journal Nature Climate Change (2023).

# The AZFP data are available in raw format at:
# Flores, Hauke; Castellani, Giulia; Wilkinson, Jeremy; Valcic, Lovro; Hoppmann, Mario; Veyssiere, Gaelle; Karcher, Michael J;
# Nicolaus, Marcel; Stroeve, Julienne C (2023): Hydroacoustic backscatter recorded by buoy 2020AZFP1 in the central Arctic Ocean 
# during Sep 2020 - May 2021. https://doi.org/10.1594/PANGAEA.954939
# This script uses a cleaned and scrutinized dataset (for methods see Flores et al. 2023), which is enclosed in the
# attached data file "Flores_AZFP_Data.RData". We use three datasets for each of the three frequencies analyzed 
# (125, 200 and 455 kHz).The data are expressed as mean volume backscattering strength (Sv), in dB re 1 m^(-1).
# In addition, this script uses subsets of the AZFP data of each frequency, containig acoustic backscatter strength integrated over the 
# depth range between the surface and the depth of the surface backscatter maximum (SBM). These data are expressed as 
# "Nautical Area Backscatter Coefficient" (NASC), in m^(-2) nm^(-2).

# The data file also contains a dataset "isolume" which defines the depth in m (+/- uncertainty range) at which the light intensity 
# under sea ice reaches a trigger level for zooplankton vertical migration, as well as a dataset "mn" which contains the biovolume of
# different zooplankton taxa sampled with a multinet prior to the deplyoment of the AZFP.

### Script author: Hauke Flores (hauke.flores@awi.de)

### END DISCLAIMER ###

#### LOAD DATA ####

  # your file directory:
    setwd("YOUR DIRECTORY") # here insert the full path of the directory where the file "Flores_AZFP_Data.RData" is stored

  # Load datasets:
    load("FloresVeyssiere_AZFP_Data.RData")
    
    library(RColorBrewer)
    
#### OVERVIEW PLOTS OF AZFP DATA (Figure 1B) ####

  ### 125 KHz ###

    ## plot 125 KHz data ##
    
    # Calculate depth for each sample bin
      KHz.125.depth <- as.numeric(names(KHz.125[14:425]))* KHz.125$Depth_stop [1] / KHz.125$Sample_count [1]
    
    dev.new (width = 1200, height =200, unit="px", noRStudioGD = TRUE)

    plot.125KHz <- filled.contour(as.numeric(KHz.125$DateTime_R), KHz.125.depth [3:100], as.matrix(KHz.125[,16:113]), # excluded top 1 m
                  col=hcl.colors(35, "viridis", rev=F),
                  zlim = c(-100, -65), ylim = c(50,0), xlim = c(as.numeric(as.POSIXlt("2020-09-18")), as.numeric(as.POSIXlt("2021-04-01"))),
                  nlevels = 35,
                  ylab="Depth (m)", xlab="", main = "125 KHz", # breaks = c(-999,-100,-95,-90,-85,-80,-75,-70,-65,-60,
                  plot.axes = {  axis (1, at=c(as.numeric(as.POSIXlt("2020-09-18")), as.numeric(as.POSIXlt("2020-10-01")), as.numeric(as.POSIXlt("2020-11-01")), 
                                          as.numeric(as.POSIXlt("2020-12-01")), as.numeric(as.POSIXlt("2021-01-01")), as.numeric(as.POSIXlt("2021-02-01")),
                                          as.numeric(as.POSIXlt("2021-03-01")), as.numeric(as.POSIXlt("2021-04-01"))), 
                                       labels = c("2020-09-18", "2020-10-01", "2020-11-01", "2020-12-01", "2021-01-01",
                                                  "2021-02-01", "2021-03-01", "2021-04-01"), tick = T)
                                 axis (2, at=c(50, 40, 30, 20, 10, 0))},
                  key.title = title (main = "Sv (db)"), cex=1.5)
        
  ### 200 KHz ###
  
    ## plot 200 KHz data ##
    
    # Calculate depth for each sample bin
    
      KHz.200.depth <- as.numeric(names(KHz.200[14:423]))* KHz.200$Depth_stop [1] / KHz.200$Sample_count [1]
    
    dev.new (width = 1200, height =200, unit="px", noRStudioGD = TRUE)

    plot.200KHz <- filled.contour(as.numeric(KHz.200$DateTime_R), KHz.200.depth [1:100], as.matrix(KHz.200[,14:113]), 
                              col=hcl.colors(35, "viridis", rev=F),
                       zlim = c(-100, -65), ylim = c(50,0), xlim = c(as.numeric(as.POSIXlt("2020-09-18")), as.numeric(as.POSIXlt("2021-04-01"))),
                    nlevels = 35,
                    ylab="Depth (m)", xlab="", main = "200 KHz", # breaks = c(-999,-100,-95,-90,-85,-80,-75,-70,-65,-60,
                plot.axes = {  axis (1, at=c(as.numeric(as.POSIXlt("2020-09-18")), as.numeric(as.POSIXlt("2020-10-01")), as.numeric(as.POSIXlt("2020-11-01")), 
                             as.numeric(as.POSIXlt("2020-12-01")), as.numeric(as.POSIXlt("2021-01-01")), as.numeric(as.POSIXlt("2021-02-01")),
                             as.numeric(as.POSIXlt("2021-03-01")), as.numeric(as.POSIXlt("2021-04-01"))), 
                             labels = c("2020-09-18", "2020-10-01", "2020-11-01", "2020-12-01", "2021-01-01",
                                        "2021-02-01", "2021-03-01", "2021-04-01"), tick = T)
                              axis (2, at=c(50, 40, 30, 20, 10, 0))},
                key.title = title (main = "Sv (db)"), cex=1.5)

  ### 455 KHz ###
    
    ## plot 455 KHz data ##    
    
    # Calculate depth for each sample bin
    
      KHz.455.depth <- as.numeric(names(KHz.455[14:418]))* KHz.455$Depth_stop [1] / KHz.455$Sample_count [1]
    
    dev.new (width = 1200, height =200, unit="px", noRStudioGD = TRUE)

    plot.455KHz <- filled.contour(as.numeric(KHz.455$DateTime_R), KHz.455.depth [1:100], as.matrix(KHz.455[,14:113]), 
                     col=hcl.colors(35, "viridis", rev=F),
                       zlim = c(-100, -65), ylim = c(50,0), xlim = c(as.numeric(as.POSIXlt("2020-09-18")), as.numeric(as.POSIXlt("2021-04-01"))),
                     nlevels=35,
                     ylab="Depth (m)", xlab="Date", main = "455 KHz",
                     axes="T", frame.plot="T", #, levels = c(-100,-95,-90,-85,-80,-75,-70,-65,-60)), 
                     plot.axes = {  axis (1, at=c(as.numeric(as.POSIXlt("2020-09-18")), as.numeric(as.POSIXlt("2020-10-01")), as.numeric(as.POSIXlt("2020-11-01")), 
                                          as.numeric(as.POSIXlt("2020-12-01")), as.numeric(as.POSIXlt("2021-01-01")), as.numeric(as.POSIXlt("2021-02-01")),
                                          as.numeric(as.POSIXlt("2021-03-01")), as.numeric(as.POSIXlt("2021-04-01"))), 
                                  labels = c("2020-09-18", "2020-10-01", "2020-11-01", "2020-12-01", "2021-01-01",
                                             "2021-02-01", "2021-03-01", "2021-04-01"), tick = T)
                                    axis (2, at=c(50, 40, 30, 20, 10, 0))},
                                  key.title = title (main = "Sv (db)"), cex=1.5)
        
### END OVERVIEW PLOTS OF AZFP DATA ###
    
#### PLOTS OF NASC VS SOLAR ANGLE (FIGURE 2A,B) ####
    
  ### Solar angle ###

  library (oce) # This library is needed to estimate solar angle from time and position data

  sola.125 <- sunAngle(KHz.125$DateTime_R, KHz.125$Longitude, KHz.125$Latitude) 

  # plot to check solar angle data:
    plot (KHz.125$Ping_index, sola.125$altitude, type="l", xaxt="n") 
      axis(1, at=KHz.125$Ping_index, labels = KHz.125$DateR, tick = F)

  ### Plots of NASC in spring and autumn ###

  ## plot layout ##

      dev.new (width = 1200, height =1500, unit="px", noRStudioGD = TRUE)
      mat <- matrix(c(1,2,3,4,0,0,0,0,5,6,7,8), 4, 3, byrow = F) # mat is the arrangement pattern figures 1-6 in 3 rows by 3 columns, the middle one as placeholder 
      nf <- layout(mat, widths = lcm(c(7,1,7)), heights = lcm(c(3,5,5,5)))
      par(mar = c(4,4,1,1))

  # tick mark every day
    tick <- seq(as.numeric(as.POSIXlt("2020-09-28")),as.numeric(as.POSIXlt("2020-10-10")), by=86400)

  ## Autumn ##

  # plot solar angle:
    solar.plot.aut <- plot(as.numeric(sola.125$time), sola.125$altitude, type="l", col="red", ylim=c(-8,-1),
                       xaxt="n", xlim = c(as.numeric(as.POSIXlt("2020-09-28")),as.numeric(as.POSIXlt("2020-10-10"))),
                       xlab ="", ylab="Sun angle (?)")                
          abline(v=seq(as.POSIXlt("2020-09-27 22:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="blue", lty=3)
          abline(v=seq(as.POSIXlt("2020-09-28 10:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="orange", lty=3)


  ## plot NASC with data only above SBM ##

    NASC.125.aut.plot <- plot(as.numeric(KHz.125.int$DateTimeR), KHz.125.int$NASC, type="p", ylim = c(0,3), 
                      xlim = c(as.numeric(as.POSIXlt("2020-09-28")),as.numeric(as.POSIXlt("2020-10-10"))), 
                      xaxt="n", xlab ="", ylab="NASC (120 KHz)", pch=20, cex=0.7, col="dark grey") 
              lines(as.numeric(KHz.125.int$DateTimeR), predict(loess(KHz.125.int$NASC ~ as.numeric(KHz.125.int$DateTimeR)
                                                   , span=0.01)), col = "dark blue")
              abline(v=seq(as.POSIXlt("2020-09-27 22:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="blue", lty=3)
              abline(v=seq(as.POSIXlt("2020-09-28 10:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="orange", lty=3)
                  
    NASC.200.aut.plot <- plot(as.numeric(KHz.200.int$DateTimeR), KHz.200.int$NASC, type="p", ylim = c(0,6), 
                          xlim = c(as.numeric(as.POSIXlt("2020-09-28")),as.numeric(as.POSIXlt("2020-10-10"))), 
                          xaxt="n", xlab ="", ylab="NASC (200 KHz)", pch=20, cex=0.7, col="dark grey") 
            lines(as.numeric(KHz.200.int$DateTimeR), predict(loess(KHz.200.int$NASC ~ as.numeric(KHz.200.int$DateTimeR)
                                                   , span=0.01)), col = "dark blue")
            abline(v=seq(as.POSIXlt("2020-09-27 22:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="blue", lty=3)
            abline(v=seq(as.POSIXlt("2020-09-28 10:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="orange", lty=3)
            
    NASC.455.aut.plot <- plot(as.numeric(KHz.455.int$DateTimeR), KHz.455.int$NASC, type="p", ylim = c(0,80), 
                        xlim = c(as.numeric(as.POSIXlt("2020-09-28")),as.numeric(as.POSIXlt("2020-10-10"))), 
                        xaxt="n", xlab ="Date", ylab="NASC (455 KHz)", pch=20, cex=0.7, col="dark grey") 
            axis(1, at = tick, labels=seq(as.POSIXlt("2020-09-28"),as.POSIXlt("2020-10-10"), by=86400), tick=T, las=1) 
            lines(as.numeric(KHz.455.int$DateTimeR), predict(loess(KHz.455.int$NASC ~ as.numeric(KHz.455.int$DateTimeR)
                                                    , span=0.01)), col = "dark blue")
            abline(v=seq(as.POSIXlt("2020-09-27 22:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="blue", lty=3)
            abline(v=seq(as.POSIXlt("2020-09-28 10:00:00"),as.POSIXlt("2020-10-10"), by=86400), col="orange", lty=3)

  ## Spring ##
 
  # plot solar angle:               
    solar.plot.spr <- plot(as.numeric(sola.125$time), sola.125$altitude, type="l", col="red", ylim=c(-10,2),
                        xaxt="n", xlim = c(as.numeric(as.POSIXlt("2021-03-04")),as.numeric(as.POSIXlt("2021-03-15"))),
                        xlab ="", ylab="")                
          abline(v=seq(as.POSIXlt("2021-03-04 04:00:00"),as.POSIXlt("2021-03-15 04:00:00"), by=86400), col="blue", lty=3)
          abline(v=seq(as.POSIXlt("2021-03-04 16:00:00"),as.POSIXlt("2021-03-15 16:00:00"), by=86400), col="orange", lty=3)

  ## plot NASC with data only above SBM ##   
        
      NASC.125.spr.plot <- plot(as.numeric(KHz.125.int$DateTimeR), KHz.125.int$NASC, type="p", ylim = c(0,1),
                          xlim = c(as.numeric(as.POSIXlt("2021-03-04")),as.numeric(as.POSIXlt("2021-03-15"))), 
                          xaxt="n", xlab ="", ylab="", pch=20, cex=0.7, col="dark grey") 
              lines(as.numeric(KHz.125.int$DateTimeR), predict(loess(KHz.125.int$NASC ~ as.numeric(KHz.125.int$DateTimeR)
                                                         , span=0.005)), col = "dark blue")
            abline(v=seq(as.POSIXlt("2021-03-04 04:00:00"),as.POSIXlt("2021-03-15 04:00:00"), by=86400), col="blue", lty=3)
            abline(v=seq(as.POSIXlt("2021-03-04 16:00:00"),as.POSIXlt("2021-03-15 16:00:00"), by=86400), col="orange", lty=3)
    
      NASC.200.spr.plot <- plot(as.numeric(KHz.200.int$DateTimeR), KHz.200.int$NASC, type="p", ylim = c(0,1),
                          xlim = c(as.numeric(as.POSIXlt("2021-03-04")),as.numeric(as.POSIXlt("2021-03-15"))), 
                          xaxt="n", xlab ="", ylab="", pch=20, cex=0.7, col="dark grey") 
            lines(as.numeric(KHz.200.int$DateTimeR), predict(loess(KHz.200.int$NASC ~ as.numeric(KHz.200.int$DateTimeR)
                                                         , span=0.005)), col = "dark blue")
            abline(v=seq(as.POSIXlt("2021-03-04 04:00:00"),as.POSIXlt("2021-03-15 04:00:00"), by=86400), col="blue", lty=3)
            abline(v=seq(as.POSIXlt("2021-03-04 16:00:00"),as.POSIXlt("2021-03-15 16:00:00"), by=86400), col="orange", lty=3)
    
      NASC.455.spr.plot <- plot(as.numeric(KHz.455.int$DateTimeR), KHz.455.int$NASC, type="p", ylim = c(0,10),
                          xlim = c(as.numeric(as.POSIXlt("2021-03-04")),as.numeric(as.POSIXlt("2021-03-15"))), 
                          xaxt="n", xlab ="Date", ylab="", pch=20, cex=0.7, col="dark grey") 
            axis(1, at = seq(as.numeric(as.POSIXlt("2021-03-04")), as.numeric(as.POSIXlt("2021-03-15")), by=86400), 
            labels=seq(as.POSIXlt("2021-03-04"),as.POSIXlt("2021-03-15"), by=86400), tick=T, las=1) 
            lines(as.numeric(KHz.455.int$DateTimeR), predict(loess(KHz.455.int$NASC ~ as.numeric(KHz.455.int$DateTimeR)
                                                           , span=0.005)), col = "dark blue")
            abline(v=seq(as.POSIXlt("2021-03-04 04:00:00"),as.POSIXlt("2021-03-15 04:00:00"), by=86400), col="blue", lty=3)
            abline(v=seq(as.POSIXlt("2021-03-04 16:00:00"),as.POSIXlt("2021-03-15 16:00:00"), by=86400), col="orange", lty=3)
            
### END NASC PLOTS ###
                      
#### ISOLUME PLOT (Figure 2C) ####

  dev.new (width = 1800, height =600, unit="px", noRStudioGD = TRUE)

  plot.455KHz <- image(as.numeric(KHz.455$DateTime_R),KHz.455.depth [1:100], as.matrix(KHz.455[,14:113]), 
                              col=hcl.colors(35, "viridis", rev=F),
                              zlim = c(-100, -65), ylim = c(50,0), xlim = c(as.numeric(as.POSIXlt("2020-09-28 12:00:00")), as.numeric(as.POSIXlt("2020-10-07 12:00:00 GMT"))),
                              ylab="Depth (m)", xlab="Date", main = "455 KHz",
                              xaxt="n") #, levels = c(-100,-95,-90,-85,-80,-75,-70,-65,-60)), #lines(seq(1:5956), KHz.455.pyc.dpt, col="white"),
                      axis (1, at=c(as.numeric(as.POSIXlt("2020-09-29")), 
                                                          as.numeric(as.POSIXlt("2020-09-30")), as.numeric(as.POSIXlt("2020-10-01")), as.numeric(as.POSIXlt("2020-10-02")),
                                                          as.numeric(as.POSIXlt("2020-10-03")), as.numeric(as.POSIXlt("2020-10-04")), as.numeric(as.POSIXlt("2020-10-05")),
                                                          as.numeric(as.POSIXlt("2020-10-06")), as.numeric(as.POSIXlt("2020-10-07"))), 
                                                          labels = c("2020-09-29", "2020-09-30", "2020-10-01", "2020-10-02",
                                                              "2020-10-03", "2020-10-04", "2020-10-05", "2020-10-06", "2020-10-07")) 
                                                   
                      axis (2, at=c(50, 40, 30, 20, 10, 0))
                              

                      lines(depth_isolume_mean ~ as.numeric(DateTime_R), isolume, col = "lightgrey", lwd=5, ylim =c(50,0))
                      lines(depth_isolume_std. ~ as.numeric(DateTime_R), isolume, col = "lightgrey", lwd=3, lty= "12", ylim =c(50,0))
                      lines(depth_isolume_std..1 ~ as.numeric(DateTime_R), isolume, col = "lightgrey", lwd=3, lty= "12",ylim =c(50,0))

### END ISOLUME PLOT ###
                        
#### PAIRED T-TEST ABOVE VERSUS BELOW TRIGGER ISOLUME ####

# We test the null hypothesis that the mean Sv in the top 50 m is not lower above the trigger isolume than below the trigger isolume.
# Data are limited to the period from 28 September to 7 October 2020, the period when the isolume is between the SBM and the ice underside.
# We use a one-sided paired t-test to test pairwise comparison of mean Sv above and below the trigger isolume at each measurement interval.

  # Limit isolume data:
    iso.cor <- isolume [isolume$DateTime_R > "2020-09-28 12:00:00" & isolume$DateTime_R < "2020-10-07 00:00:00",]
                      
  ### 125 KHz ###

    # Limit and format datset:
      KHz.125.pyc.ab <- KHz.125 [KHz.125$DateTime_R > "2020-09-28 12:00:00" & KHz.125$DateTime_R < "2020-10-07 00:00:00",]
      KHz.125.pyc.ab.depth <- c(1:412) * KHz.125.pyc.ab$Depth_stop [1] / KHz.125.pyc.ab$Sample_count [1]

    # Transpose dataset and create data frame:
      KHz.125.pyc.ab.t <- as.data.frame(t(KHz.125.pyc.ab [,c(14:425)]))
      KHz.125.pyc.ab.t[KHz.125.pyc.ab.t < -200 | KHz.125.pyc.ab.t > -70] <- NA #remove bad data

    # Transform Sv (logarhitmic) to sv (linear):
      KHz.125.pyc.ab.t <- 10^(KHz.125.pyc.ab.t/10)

    ## Create vectors of mean sv above and below the SBM, respectivly ##

      # Create a list of dataframes
        df_list <- lapply(seq_along(KHz.125.pyc.ab.t), function(i) {
  
      # Extract column i from df
        col_i <- KHz.125.pyc.ab.t[, i]
  
      # Combine col_i and Dpt into a dataframe
        df_i <- data.frame(Sv = col_i, Dpt = c(KHz.125.pyc.ab.depth))
  
      # Remove rows with NA in either column
        df_i <- df_i[complete.cases(df_i), ]
  
      # Return the resulting dataframe
        return(df_i)
      })

    # Initialize two lists to store the mean Sv values
      mean_below <- vector("list", length = length(df_list))
      mean_above <- vector("list", length = length(df_list))

    # Loop over elements of df_list
      for(i in seq_along(df_list)) {
  
      # Subset the dataframe to rows where Dpt is above or below the corresponding I value
        below_i <- df_list[[i]][df_list[[i]]$Dpt > iso.cor$depth_isolume_mean[i], "Sv"]
        above_i <- df_list[[i]][df_list[[i]]$Dpt <= iso.cor$depth_isolume_mean[i], "Sv"]
  
      # Calculate the mean Sv values and store them in the corresponding list
        mean_below[[i]] <- mean(below_i)
        mean_above[[i]] <- mean(above_i)
        }

    # Combine the mean Sv values into two vectors
      mean_above <- unlist(mean_above)
      mean_below <- unlist(mean_below)

    ## back-transform from linear sv to logahrithmic Sv:##
      mean_above <- 10*log10(mean_above)
      mean_below <- 10*log10(mean_below)

    ## t-test (pairwise) ##

      # plot data above and below
        plot (mean_above)
        plot (mean_below)
        plot (mean_above-mean_below, type="l")

      # Histograms to check for near-normal distribution of data
        hist (mean_above)
        hist (mean_below)

      # t-test #
        t.test(mean_above, mean_below, paired=T, alternative = "less") # t = -29.707, df = 586, p-value < 2.2e-16; mean difference -6.237756 

  ### 200 KHz ###  

    # Limit and format datset:
      KHz.200.pyc.ab <- KHz.200 [KHz.200$DateTime_R > "2020-09-28" & KHz.200$DateTime_R < "2020-10-08 22:00:00",]
      KHz.200.pyc.ab.depth <- c(1:410) * KHz.200.pyc.ab$Depth_stop [1] / KHz.200.pyc.ab$Sample_count [1]

    # Transpose dataset and create data frame:
      KHz.200.pyc.ab.t <- as.data.frame(t(KHz.200.pyc.ab [,c(14:423)]))
      KHz.200.pyc.ab.t[KHz.200.pyc.ab.t < -200 | KHz.200.pyc.ab.t > -50] <- NA #remove bad data


    # Transform Sv (logarhitmic) to sv (linear):
      KHz.200.pyc.ab.t <- 10^(KHz.200.pyc.ab.t/10)

    ## Create vectors of mean sv above and below the SBM, respectivly ##

      # Create a list of dataframes
        df_list <- lapply(seq_along(KHz.200.pyc.ab.t), function(i) {
  
        # Extract column i from df
          col_i <- KHz.200.pyc.ab.t[, i]
  
        # Combine col_i and Dpt into a dataframe
          df_i <- data.frame(Sv = col_i, Dpt = KHz.200.pyc.ab.depth)
  
        # Remove rows with NA in either column
        df_i <- df_i[complete.cases(df_i), ]
  
        # Return the resulting dataframe
          return(df_i)
        })

      # Initialize two lists to store the mean Sv values
        mean_below <- vector("list", length = length(df_list))
        mean_above <- vector("list", length = length(df_list))

      # Loop over elements of df_list
        for(i in seq_along(df_list)) {
  
        # Subset the dataframe to rows where Dpt is above or below the corresponding I value
          below_i <- df_list[[i]][df_list[[i]]$Dpt > iso.cor$depth_isolume_mean[i], "Sv"]
          above_i <- df_list[[i]][df_list[[i]]$Dpt <= iso.cor$depth_isolume_mean[i], "Sv"]
  
        # Calculate the mean Sv values and store them in the corresponding list
          mean_below[[i]] <- mean(below_i)
          mean_above[[i]] <- mean(above_i)
        }

      # Combine the mean Sv values into two vectors
        mean_above <- unlist(mean_above)
        mean_below <- unlist(mean_below)

    # back-transform from linear sv to logahrithmic Sv:
      mean_above <- 10*log10(mean_above)
      mean_below <- 10*log10(mean_below)

    ## t-test (pairwise) ##
    
    # plot data above and below
      plot (mean_above)
      plot (mean_below)
      plot (mean_above-mean_below, type="l")

    # Histograms to check for near-normal distribution of data
      hist (mean_above)
      hist (mean_below)

    # t-test #
      t.test(mean_above, mean_below, paired=T, alternative = "less") # t = -32.095, df = 585, p-value < 2.2e-16; mean difference  -7.865309 

  ### 455 KHz ###  
      
    # Limit and format datset:
      KHz.455.pyc.ab <- KHz.455 [KHz.455$DateTime_R > "2020-09-28 12:00:00" & KHz.455$DateTime_R < "2020-10-07 00:00:00",]
      KHz.455.pyc.ab.depth <- c(1:405) * KHz.455.pyc.ab$Depth_stop [1] / KHz.455.pyc.ab$Sample_count [1]
      
    # Transpose dataset and create data frame:
      KHz.455.pyc.ab.t <- as.data.frame(t(KHz.455.pyc.ab [,c(14:418)]))
      KHz.455.pyc.ab.t[KHz.455.pyc.ab.t < -200 | KHz.455.pyc.ab.t > -50] <- NA #remove bad data
      
    # Transform Sv (logarhitmic) to sv (linear):
      KHz.455.pyc.ab.t <- 10^(KHz.455.pyc.ab.t/10)
      
    ## Create vectors of mean sv above and below the SBM, respectivly ##  
      
    # Create a list of dataframes
      df_list <- lapply(seq_along(KHz.455.pyc.ab.t), function(i) {
        
      # Extract column i from df
        col_i <- KHz.455.pyc.ab.t[, i]
        
      # Combine col_i and Dpt into a dataframe
        df_i <- data.frame(Sv = col_i, Dpt = KHz.455.pyc.ab.depth)
        
      # Remove rows with NA in either column
        df_i <- df_i[complete.cases(df_i), ]
        
        # Return the resulting dataframe
        return(df_i)
      })
      
    # Initialize two lists to store the mean sv values
      mean_below <- vector("list", length = length(df_list))
      mean_above <- vector("list", length = length(df_list))
      
    # Loop over elements of df_list
      for(i in seq_along(df_list)) {
        
      # Subset the dataframe to rows where Dpt is above or below the corresponding I value
        below_i <- df_list[[i]][df_list[[i]]$Dpt > iso.cor$depth_isolume_mean[i], "Sv"]
        above_i <- df_list[[i]][df_list[[i]]$Dpt <= iso.cor$depth_isolume_mean[i], "Sv"]
        
      # Calculate the mean Sv values and store them in the corresponding list
        mean_below[[i]] <- mean(below_i)
        mean_above[[i]] <- mean(above_i)
        
      }
      
    # Combine the mean Sv values into two vectors
      mean_above <- unlist(mean_above)
      mean_below <- unlist(mean_below)
      
    ## back-transform from linear sv to logahrithmic Sv: ##
      mean_above <- 10*log10(mean_above)
      mean_below <- 10*log10(mean_below)
      
    ## t-test (pairwise) ##
      
    # plot data above and below
      plot (mean_above)
      plot (mean_below)
      plot (mean_above-mean_below, type="l") # if mean Sv above isolume is lower than below, the value must be negative 
      
    # Histograms to check for near-normal distribution of data
      hist (mean_above)
      hist (mean_below)
      
    # t-test #
      t.test(mean_above, mean_below, paired=T, alternative = "less") # t = -24.485, df = 586, p-value < 2.2e-16; mean difference -3.93981; df is not 784, because 
      
    # (there are no values above the isolume in the last days of the period)
      
      
### END PAIRED T-TESTS ###

#### MULTINET DATA ####

# This plot was used in Extended Data Figure 3b

  mn <- mn [order(mn$Biovolume.perc, decreasing=T),]      
  
  dev.new (width = 1200, height =1200, unit="px", noRStudioGD = TRUE) 
  
  par(mar = c(8, 4, 4, 2) + 0.1)
  barplot(mn$Biovolume.perc, names.arg=mn$Taxon, col = "darkcyan",
          ylim = c(0,70), ylab = "Relative biovolume (%)",
          las=2)

### END MULTINET DATA ###

#### END OF SCRIPT ####

